Struct FnContext
struct FnContext { ... }
Provides the calling context to a closure called by join_context.
Implementations
impl FnContext
fn migrated(self: &Self) -> boolReturns
trueif the closure was called from a different thread than it was provided from.
impl Debug for FnContext
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for FnContext
impl RefUnwindSafe for FnContext
impl Send for FnContext
impl Sync for FnContext
impl Unpin for FnContext
impl UnsafeUnpin for FnContext
impl UnwindSafe for FnContext
impl<T> Any for FnContext
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for FnContext
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for FnContext
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for FnContext
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Pointable for FnContext
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T, U> Into for FnContext
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for FnContext
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for FnContext
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>